==> react-molecule-coachmark-0.2.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import Joyride, { ACTIONS, EVENTS, LIFECYCLE, STATUS } from 'react-joyride';
import PropTypes from 'prop-types';
import { DEFAULT_SCROLL_DURATION, DEFAULT_SCROLL_OFFSET, DEFAULT_SPOTLIGHT_PADDING, STEP_BEACON_PLACEMENT_TYPES, STEP_PLACEMENT_TYPES } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
var MoleculeCoachmark = function MoleculeCoachmark(_ref) {
  var steps = _ref.steps,
    beaconComponent = _ref.beaconComponent,
    callback = _ref.callback,
    _ref$continuous = _ref.continuous,
    continuous = _ref$continuous === void 0 ? true : _ref$continuous,
    _ref$debug = _ref.debug,
    debug = _ref$debug === void 0 ? false : _ref$debug,
    _ref$disableCloseOnEs = _ref.disableCloseOnEsc,
    disableCloseOnEsc = _ref$disableCloseOnEs === void 0 ? false : _ref$disableCloseOnEs,
    _ref$disableOverlay = _ref.disableOverlay,
    disableOverlay = _ref$disableOverlay === void 0 ? false : _ref$disableOverlay,
    _ref$disableOverlayCl = _ref.disableOverlayClose,
    disableOverlayClose = _ref$disableOverlayCl === void 0 ? false : _ref$disableOverlayCl,
    _ref$disableScrolling = _ref.disableScrolling,
    disableScrolling = _ref$disableScrolling === void 0 ? false : _ref$disableScrolling,
    _ref$disableScrollPar = _ref.disableScrollParentFix,
    disableScrollParentFix = _ref$disableScrollPar === void 0 ? false : _ref$disableScrollPar,
    floaterProps = _ref.floaterProps,
    _ref$getHelpers = _ref.getHelpers,
    getHelpers = _ref$getHelpers === void 0 ? null : _ref$getHelpers,
    _ref$hideBackButton = _ref.hideBackButton,
    hideBackButton = _ref$hideBackButton === void 0 ? false : _ref$hideBackButton,
    _ref$hideCloseButton = _ref.hideCloseButton,
    hideCloseButton = _ref$hideCloseButton === void 0 ? false : _ref$hideCloseButton,
    _ref$run = _ref.run,
    run = _ref$run === void 0 ? true : _ref$run,
    _ref$scrollOffset = _ref.scrollOffset,
    scrollOffset = _ref$scrollOffset === void 0 ? DEFAULT_SCROLL_OFFSET : _ref$scrollOffset,
    _ref$scrollDuration = _ref.scrollDuration,
    scrollDuration = _ref$scrollDuration === void 0 ? DEFAULT_SCROLL_DURATION : _ref$scrollDuration,
    _ref$scrollToFirstSte = _ref.scrollToFirstStep,
    scrollToFirstStep = _ref$scrollToFirstSte === void 0 ? false : _ref$scrollToFirstSte,
    _ref$showProgress = _ref.showProgress,
    showProgress = _ref$showProgress === void 0 ? false : _ref$showProgress,
    _ref$shopSkipButton = _ref.shopSkipButton,
    shopSkipButton = _ref$shopSkipButton === void 0 ? false : _ref$shopSkipButton,
    _ref$spotlightClicks = _ref.spotlightClicks,
    spotlightClicks = _ref$spotlightClicks === void 0 ? false : _ref$spotlightClicks,
    _ref$spotlightPadding = _ref.spotlightPadding,
    spotlightPadding = _ref$spotlightPadding === void 0 ? DEFAULT_SPOTLIGHT_PADDING : _ref$spotlightPadding,
    stepIndex = _ref.stepIndex,
    styles = _ref.styles;
  return /*#__PURE__*/_jsx(Joyride, _extends({
    steps: steps,
    beaconComponent: beaconComponent,
    callback: callback,
    continuous: continuous,
    debug: debug,
    disableCloseOnEsc: disableCloseOnEsc,
    disableOverlay: disableOverlay,
    disableOverlayClose: disableOverlayClose,
    disableScrolling: disableScrolling,
    disableScrollParentFix: disableScrollParentFix,
    floaterProps: floaterProps
  }, getHelpers && {
    getHelpers: getHelpers
  }, {
    styles: {
      options: _extends({
        zIndex: 9999
      }, styles)
    },
    hideBackButton: hideBackButton,
    hideCloseButton: hideCloseButton,
    run: run,
    scrollOffset: scrollOffset,
    scrollDuration: scrollDuration,
    scrollToFirstStep: scrollToFirstStep,
    showProgress: showProgress,
    shopSkipButton: shopSkipButton,
    spotlightClicks: spotlightClicks,
    spotlightPadding: spotlightPadding,
    stepIndex: stepIndex
  }));
};
MoleculeCoachmark.displayName = 'MoleculeCoachmark';
export { ACTIONS as moleculeCoachmarkActions };
export { EVENTS as moleculeCoachmarkEvents };
export { STATUS as moleculeCoachmarkStatus };
export { LIFECYCLE as moleculeCoachmarkLifeCycle };
export default MoleculeCoachmark;

==> react-molecule-coachmark-0.4.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import Joyride, { ACTIONS, EVENTS, LIFECYCLE, STATUS } from 'react-joyride';
import PropTypes from 'prop-types';
import { atomButtonColors, atomButtonDesigns, atomButtonShapes, atomButtonSizes } from '@s-ui/react-atom-button';
import Injector from '@s-ui/react-primitive-injector';
import DefaultTooltip from './Tooltip/index.js';
import { DEFAULT_SCROLL_DURATION, DEFAULT_SCROLL_OFFSET, DEFAULT_SPOTLIGHT_PADDING, DEFAULT_TOOLTIP_ACTION_BUTTONS_IDS, DEFAULT_Z_INDEX, STEP_BEACON_PLACEMENT_TYPES, STEP_PLACEMENT_TYPES } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
var MoleculeCoachmark = function MoleculeCoachmark(_ref) {
  var beaconComponent = _ref.beaconComponent,
    callback = _ref.callback,
    _ref$continuous = _ref.continuous,
    continuous = _ref$continuous === void 0 ? true : _ref$continuous,
    _ref$debug = _ref.debug,
    debug = _ref$debug === void 0 ? false : _ref$debug,
    defaultTooltipOptions = _ref.defaultTooltipOptions,
    _ref$disableCloseOnEs = _ref.disableCloseOnEsc,
    disableCloseOnEsc = _ref$disableCloseOnEs === void 0 ? false : _ref$disableCloseOnEs,
    _ref$disableOverlay = _ref.disableOverlay,
    disableOverlay = _ref$disableOverlay === void 0 ? false : _ref$disableOverlay,
    _ref$disableOverlayCl = _ref.disableOverlayClose,
    disableOverlayClose = _ref$disableOverlayCl === void 0 ? true : _ref$disableOverlayCl,
    _ref$disableScrolling = _ref.disableScrolling,
    disableScrolling = _ref$disableScrolling === void 0 ? false : _ref$disableScrolling,
    _ref$disableScrollPar = _ref.disableScrollParentFix,
    disableScrollParentFix = _ref$disableScrollPar === void 0 ? false : _ref$disableScrollPar,
    floaterProps = _ref.floaterProps,
    _ref$getHelpers = _ref.getHelpers,
    getHelpers = _ref$getHelpers === void 0 ? null : _ref$getHelpers,
    _ref$hideBackButton = _ref.hideBackButton,
    hideBackButton = _ref$hideBackButton === void 0 ? false : _ref$hideBackButton,
    _ref$hideCloseButton = _ref.hideCloseButton,
    hideCloseButton = _ref$hideCloseButton === void 0 ? false : _ref$hideCloseButton,
    locale = _ref.locale,
    _ref$run = _ref.run,
    run = _ref$run === void 0 ? true : _ref$run,
    _ref$scrollDuration = _ref.scrollDuration,
    scrollDuration = _ref$scrollDuration === void 0 ? DEFAULT_SCROLL_DURATION : _ref$scrollDuration,
    _ref$scrollOffset = _ref.scrollOffset,
    scrollOffset = _ref$scrollOffset === void 0 ? DEFAULT_SCROLL_OFFSET : _ref$scrollOffset,
    _ref$scrollToFirstSte = _ref.scrollToFirstStep,
    scrollToFirstStep = _ref$scrollToFirstSte === void 0 ? false : _ref$scrollToFirstSte,
    _ref$shopSkipButton = _ref.shopSkipButton,
    shopSkipButton = _ref$shopSkipButton === void 0 ? false : _ref$shopSkipButton,
    _ref$showProgress = _ref.showProgress,
    showProgress = _ref$showProgress === void 0 ? false : _ref$showProgress,
    _ref$spotlightClicks = _ref.spotlightClicks,
    spotlightClicks = _ref$spotlightClicks === void 0 ? false : _ref$spotlightClicks,
    _ref$spotlightPadding = _ref.spotlightPadding,
    spotlightPadding = _ref$spotlightPadding === void 0 ? DEFAULT_SPOTLIGHT_PADDING : _ref$spotlightPadding,
    stepIndex = _ref.stepIndex,
    steps = _ref.steps,
    styles = _ref.styles,
    CustomTooltipComponent = _ref.tooltipComponent;
  return /*#__PURE__*/_jsx(Joyride, _extends({
    beaconComponent: beaconComponent,
    callback: callback,
    continuous: continuous,
    debug: debug,
    disableCloseOnEsc: disableCloseOnEsc,
    disableOverlay: disableOverlay,
    disableOverlayClose: disableOverlayClose,
    disableScrolling: disableScrolling,
    disableScrollParentFix: disableScrollParentFix,
    floaterProps: floaterProps
  }, getHelpers && {
    getHelpers: getHelpers
  }, {
    hideBackButton: hideBackButton,
    hideCloseButton: hideCloseButton,
    locale: locale,
    run: run,
    scrollDuration: scrollDuration,
    scrollOffset: scrollOffset,
    scrollToFirstStep: scrollToFirstStep,
    shopSkipButton: shopSkipButton,
    showProgress: showProgress,
    spotlightClicks: spotlightClicks,
    spotlightPadding: spotlightPadding,
    stepIndex: stepIndex,
    steps: steps,
    styles: _extends({
      options: _extends({
        zIndex: DEFAULT_Z_INDEX
      }, styles == null ? void 0 : styles.options)
    }, styles == null ? void 0 : styles.components)
    // eslint-disable-next-line react/no-unstable-nested-components
    ,
    tooltipComponent: function tooltipComponent(props) {
      return /*#__PURE__*/_jsx(Injector, _extends({}, props, {
        defaultTooltipOptions: defaultTooltipOptions,
        showProgress: showProgress,
        hideBackButton: hideBackButton,
        children: CustomTooltipComponent ? /*#__PURE__*/_jsx(CustomTooltipComponent, {}) : /*#__PURE__*/_jsx(DefaultTooltip, {})
      }));
    }
  }));
};
MoleculeCoachmark.displayName = 'MoleculeCoachmark';
export { ACTIONS as moleculeCoachmarkActions };
export { EVENTS as moleculeCoachmarkEvents };
export { STATUS as moleculeCoachmarkStatus };
export { LIFECYCLE as moleculeCoachmarkLifeCycle };
export { DEFAULT_TOOLTIP_ACTION_BUTTONS_IDS as moleculeCoachmarkActionButtonIds };
export default MoleculeCoachmark;
